;;; selectable-font.el --- Make Font for frames easy selectable

;; Copyright (C) 2003  Free Software Foundation, Inc.

;; Author: Sascha Wilde <swilde@sha-bang.de>
;; Keywords: convenience, frames

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; provides features similar to the alternative fonts in xterm

;;; Code:

(defvar selectable-fonts-list 
  '("-*-fixed-medium-r-*-*-12-*-*-*-*-*-iso8859-1"
    "-*-fixed-medium-r-*-*-14-*-*-*-*-*-iso8859-1"
    "-*-fixed-medium-r-*-*-15-*-*-*-*-*-iso8859-1"
    "-*-fixed-medium-r-*-*-18-*-*-*-*-*-iso8859-1"
    "-*-fixed-medium-r-*-*-20-*-*-*-*-*-iso8859-1"
    "-*-fixed-medium-r-*-*-24-*-*-*-*-*-iso8859-1"
    "-*-courier-medium-r-*-*-14-*-*-*-*-*-*-1"
    "-*-courier-medium-r-*-*-18-*-*-*-*-*-*-1"
    "-*-Courier-medium-r-*-*-24-*-*-*-*-*-*-1")
  "*List of fonts selectable by \\[select-next-selectable-font]
 and \\[select-prev-selectable-font]")

(defvar default-selectable-font 
  "-*-fixed-medium-r-*-*-15-*-*-*-*-*-iso8859-1"
  "Default font for new frames")

(add-to-list 'default-frame-alist `(font . ,default-selectable-font))

(defun select-next-selectable-font (direction)
  "Interactive function to elect next font from selectable-fonts-list
for current frame"
  (interactive "p")
  (if (null (frame-parameter nil 'selected-selectable-font))
	    (modify-frame-parameters
	     nil `((selected-selectable-font . ,default-selectable-font))))
  (let ((new-selected-font (cadr (member (frame-parameter 
					  nil 'selected-selectable-font)
					 (if (< direction 0)
					     (reverse selectable-fonts-list)
					   selectable-fonts-list)))))
    (if (not (null new-selected-font))
	(progn
	  (modify-frame-parameters
	   nil `((selected-selectable-font . ,new-selected-font)))
	  (set-default-font (message new-selected-font))))))

(defun select-prev-selectable-font ()
  (interactive)
  (select-next-selectable-font -1))

;; bind ower new fontselection commands	
(global-set-key [?\s-\+] 'select-next-selectable-font)
(global-set-key [?\s-\-] 'select-prev-selectable-font)

(provide 'selectable-fonts)
;;; selectable-font.el ends here
